# magicgui.widgets

```{eval-rst}
.. automodule:: magicgui.widgets

Functions
=========

.. autosummary::
   :nosignatures:
   :toctree: ../_autosummary

   create_widget

.. currentmodule:: magicgui.widgets


Value Widgets
=============

.. autosummary::
   :nosignatures:
   :toctree: ../_autosummary

   Label
   LineEdit
   LiteralEvalLineEdit
   TextEdit
   FileEdit
   RangeEdit
   SliceEdit
   DateTimeEdit
   DateEdit
   TimeEdit

Button Widgets
--------------

.. autosummary::
   :nosignatures:
   :toctree: ../_autosummary

   PushButton
   CheckBox
   RadioButton

Ranged Widgets
--------------

.. autosummary::
   :nosignatures:
   :toctree: ../_autosummary

   SpinBox
   FloatSpinBox

Slider Widgets
^^^^^^^^^^^^^^

.. autosummary::
   :nosignatures:
   :toctree: ../_autosummary

   Slider
   FloatSlider
   LogSlider
   ProgressBar

Categorical Widgets
-------------------

.. autosummary::
   :nosignatures:
   :toctree: ../_autosummary

   ComboBox

Container Widgets
=================

.. autosummary::
   :nosignatures:
   :toctree: ../_autosummary

   Container
   FunctionGui


```
